@@ -254,6 +254,12 @@
   (when skk-dcomp-activate
     (skk-dcomp-after-delete-backward-char)))
 
+;;;###autoload
+(let ((property (if (featurep 'xemacs)
+		    'pending-del
+		  'delete-selection)))
+  (put 'skk-kanagaki-bs property 'supersede))
+
 ;;;###autoload
 (defun skk-kanagaki-esc (&optional arg)
   ;; OASYS $B$K$*$1$k<h$j>C$75!G=$NBe$o$j!#(B $B$H$j$"$($:(B keyboard-quit $B$N>l9g$HF1MM(B
