@@ -5,10 +5,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.114 2007/04/29 22:44:17 skk-cvs Exp $
+;; Version: $Id: skk-annotation.el,v 1.133 2007/08/17 14:36:08 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2007/04/29 22:44:17 $
+;; Last Modified: $Date: 2007/08/17 14:36:08 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -299,7 +299,10 @@
 		    (eq skk-henkan-mode 'active))
 		(if digit
 		    t
-		  (skk-annotation-wikipedia-message))
+		  (skk-annotation-message (if (and annotation
+						   (> (length annotation) 0))
+					      'annotation
+					    nil)))
 		(condition-case nil
 		    (progn
 		      (setq event (next-command-event)
@@ -408,8 +411,10 @@
       (skk-unread-event event))))
 
 ;;;###autoload
-(defun skk-annotation-wikipedia-message ()
-  (when skk-verbose
+(defun skk-annotation-message (&optional situation)
+  (when (and skk-verbose
+	     (not (or skk-isearch-switch
+		      (skk-in-minibuffer-p))))
     (unless skk-annotation-wikipedia-message
       (let* ((key (key-description skk-annotation-wikipedia-key))
 	     (string (format "{prefix %s}" (if (equal key "TAB")
@@ -421,11 +426,44 @@
 	  (setq string (format "%s[C-%d]%s" string (1+ i) source))
 	  (setq i (1+ i)))
 	(setq skk-annotation-wikipedia-message string)))
+    (unless skk-annotation-message
+      (let* ((key-copy (or (key-description skk-annotation-copy-key)
+			   "$BL$Dj5A(B"))
+	     (key-browse (or (key-description skk-annotation-browse-key)
+			     "$BL$Dj5A(B")))
+	(setq skk-annotation-message
+	      (format "{$B%"%N%F!<%7%g%s(B}[%s]$B%3%T!<(B[%s]URL$B%V%i%&%:(B"
+		      key-copy key-browse))))
     (condition-case nil
-	(when (skk-sit-for skk-verbose-wait)
-	  (message "%s" skk-annotation-wikipedia-message))
+	(cond ((eq situation 'annotation)
+	       (if (skk-sit-for skk-verbose-wait)
+		   (let ((i 0))
+		     (catch 'loop
+		       (while (< i 20)
+			 (message "%s" skk-annotation-message)
+			 (unless (skk-sit-for 5.5)
+			   (throw 'loop nil))
+			 (message "%s" skk-annotation-wikipedia-message)
+			 (unless (skk-sit-for 5.5)
+			   (throw 'loop nil))
+			 (setq i (1+ i))))
+		     (message nil))
+		 nil))
+	      (t
+	       (when (skk-sit-for skk-verbose-wait)
+		 (message "%s" skk-annotation-wikipedia-message))))
       (quit
-       (keyboard-quit))))
+       (cond
+	((eq skk-henkan-mode 'active)
+	 (setq skk-henkan-count 0)
+	 (skk-unread-event
+	  (character-to-event
+	   (aref
+	    (car (where-is-internal 'skk-previous-candidate skk-j-mode-map))
+	    0))))
+	(t
+	 (keyboard-quit))))))
+  ;; $B>o$K(B t $B$rJV$9(B
   t)
 
 (defun skk-annotation-find-url (string)
@@ -465,7 +503,7 @@
 	  (when minibuf-p
 	    (select-window (minibuffer-window)))
 	  ;;
-	  (skk-annotation-wikipedia-message)
+	  (skk-annotation-message 'annotation)
 	  ;;
 	  (setq event (next-command-event))
 	  (when (skk-key-binding-member
@@ -859,14 +897,14 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
   (let ((cache-buffer (format " *skk %s %s" source word))
 	;; html2text $B$,@5$7$/07$($J$$(B tag $B$O0J2<$N%j%9%H$K;XDj$9$k(B
 	(html2text-remove-tag-list
-	 (append '("a" "span" "table" "tr" "td" "h2" "h3" "h4" "small"
+	 (append '("a" "span" "table" "tr" "td" "h2" "h3" "h4" "h5" "small"
 		   "code")
 		 html2text-remove-tag-list))
 	(html2text-format-tag-list
 	 (append '(("sup" . skk-annotation-wikipedia-clean-sup)
 		   ("sub" . skk-annotation-wikipedia-clean-sub))
 		 html2text-format-tag-list))
-	buffer note aimai continue nop point top pt1 pt2 btag etag)
+	buffer note aimai continue nop point top pt1 pt2 btag etag end)
     (if (get-buffer cache-buffer)
 	(with-current-buffer cache-buffer
 	  (setq note (buffer-string)))
@@ -906,7 +944,8 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 	      (goto-char (point-min))
 	      (if (save-excursion
 		    (re-search-forward "\
-\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\\)"
+\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\
+\\|:Badtitle\\)"
 				       nil t))
 		  ;; $B9`L\$,$J$$>l9g(B
 		  (erase-buffer)
@@ -915,9 +954,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 		;;
 		(goto-char (point-min))
 		(when (re-search-forward
-		       ;; XXX $B$^$@IT40A4(B
-		       "<h2>.*<span class=\"mw-headline\">\
-\\(<a href=.+>\\)?\\($BF|K\8l(B\\|$B1Q8l(B\\)\\(</a>\\)?\</span></h2>"
+		       skk-annotation-ja-wiktionary-lang-regexp
 		       nil t)
 		  (save-excursion
 		    (goto-char (match-end 2))
@@ -925,33 +962,24 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 		  (delete-region (point-min) (match-beginning 0))
 		  (setq top (point))
 		  (when (re-search-forward
-			 "<h2>.*<span class=\"mw-headline\">\
-\\(<a href=.+>\\)?.+$B8l(B\\(</a>\\)?</span></h2>"
+			 skk-annotation-ja-wiktionary-lang-regexp
 			 nil t)
-		    (delete-region (match-beginning 0) (point-max))))
-		;; <div> $B$r=|5n$9$k(B
-		(goto-char (point-min))
-		(while (re-search-forward
-			"<div class=\"\\(infl-table\\)\".*>" nil t)
-		  (setq point (match-beginning 0))
-		  (goto-char point)
-		  (search-forward "</div>" nil t)
-		  (delete-region point (point))
-		  (goto-char point))
+		    (delete-region (setq pt1 (match-beginning 0))
+				   (point-max))))
 		;;
 		(setq point top)
 		(goto-char (point-min))
+		;; ja.wiktionary $B$N=q<0$,(B en.wiktionary $B$[$I@0$C$F$$$J$$$N$G(B
+		;; workaround
+		(unless
+		    (save-excursion
+		       (re-search-forward
+			skk-annotation-ja-wiktionary-part-of-speech-regexp
+			nil t))
+		  (setq point pt1))
+		;;
 		(while (re-search-forward
-			;; XXX $B$^$@IT40A4(B
-			"<span class=\"mw-headline\">\
-\\(<a href=.+>\\)?\
-\\(\
-\\(\\($B8GM-(B\\|\\($B?M>N(B\\)?$BBe(B\\)?$BL>(B\\|\\($B=u(B\\)?$BF0(B\\|$B7AMFF0(B?\\|\
-$B@\B3(B\\|$BA0CV(B\\|$BI{(B\\|$B4'(B\\)\
-$B;l(B.*\
-\\|$B4A;z:.$8$jI=5-(B\\|$B0U5A(B\\|$BN,8l(B\\)\
-\\(</a>\\)?\
-</span>"
+			skk-annotation-ja-wiktionary-part-of-speech-regexp
 			nil t)
 		  (setq nop t)
 		  (save-match-data
@@ -979,13 +1007,20 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 			(setq point pt2)
 			(goto-char point)))))
 		;;
+		;; ja.wiktionary $B$N=q<0$,(B en.wiktionary $B$[$I@0$C$F$$$J$$$N$G(B
+		;; $B>C$7$9$.$F$7$^$&4m81@-$"$j!#(B
 		(when point
 		  (delete-region point (point-max)))
 		;; ($BMQNc$J$I$r=|$/(B -- $B=|$+$J$$$[$&$,$$$$!)(B)
-		(skk-annotation-wikipedia-remove-nested "<ul>" "</ul>")
+		;; ja.wiktionary $B$O(B en.wiktionary $B$HA4$/E}0l$5$l$?=q$-J}$K$O(B
+		;; $B$J$C$F$$$J$$$N$G!"(Bul $B$r=|$/$H>pJs$,$[$H$s$I;D$i$J$$>l9g$,(B
+		;; $B$"$k(B
+		;; (skk-annotation-wikipedia-remove-nested "<ul>" "</ul>")
 		(skk-annotation-wikipedia-remove-nested "<dl>" "</dl>")
-		(skk-annotation-wikipedia-remove-nested "<table.*>"
+		(skk-annotation-wikipedia-remove-nested "<table[^<]*>"
 							"</table>")
+		(skk-annotation-wikipedia-remove-nested "\
+<div class=\"\\(infl-table\\|thumb.+\\)\"[^<]*>" "</div>" "<div[^<]*>")
 		;;
 		(goto-char (point-min))
 		(while (re-search-forward
@@ -997,7 +1032,8 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 	      (goto-char (point-min))
 	      (if (save-excursion
 		    (re-search-forward "\
-\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\\)"
+\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\
+\\|:Badtitle\\)"
 				       nil t))
 		  ;; $B9`L\$,$J$$>l9g(B
 		  (erase-buffer)
@@ -1006,11 +1042,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 		;;
 		(goto-char (point-min))
 		(when (re-search-forward
-		       "<h2>.*<span class=\"mw-headline\">\
-\\(<a href=.+>\\)?\
-\\(English\\|Translingual\\)\
-\\(</a>\\)?\
-</span></h2>"
+		       skk-annotation-en-wiktionary-lang-regexp
 		       nil t)
 		  (save-excursion
 		    (goto-char (match-end 2))
@@ -1018,47 +1050,14 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 		  (delete-region (point-min) (match-beginning 0))
 		  (setq top (point))
 		  (when (re-search-forward
-			 ;; XXX $B$^$@IT40A4(B
-			 "<h2>.*<span class=\"mw-headline\">\
-\\(<a href=.+>\\)?\
-\\(Afrikaans\\|Ainu\\|Amoy\\|Amuzgo\\|Aragonese\\|Bosnian\\|Cantonese\
-\\|Catalan\\|Crimean Tatar\\|Croatian\
-\\|Czech\\\|Danish\\|Dutch\\|Egyptian\\|Esperanto\\|Estonian\\|Faroese\
-\\|Finnish\\|French\\|German\\|Greek\\|Hungarian\\|Interlingua\\|Irish\
-\\|Italian\\|Japanese\\|Krisa\\|Latin\\|Mandarin\\|Northern Sami\
-\\|Norwegian\\|Novial\\|Old English\\|Polish\\|Potuguese\\|Romanian\
-\\|Scottish Gaelic\\|Serbian\\|Slovak\\|Slovene\\|Spanish\\|Swahili\
-\\|Swedish\\|Torres Strait Creole\\|Turkish\\|Tz'utujil\\)\
-\\(</a>\\)?\
-</span></h2>"
+			 skk-annotation-en-wiktionary-lang-regexp
 			 nil t)
 		    (delete-region (match-beginning 0) (point-max))))
-		;; <div> $B$r=|5n$9$k(B
-		(goto-char (point-min))
-		(while (re-search-forward
-			"<div class=\"\\(infl-table\\)\".*>" nil t)
-		  (setq point (match-beginning 0))
-		  (goto-char point)
-		  (search-forward "</div>" nil t)
-		  (delete-region point (point))
-		  (goto-char point))
 		;;
 		(setq point top)
 		(goto-char (point-min))
 		(while (re-search-forward
-			;; XXX $B$^$@IT40A4(B
-			"<span class=\"mw-headline\">\
-\\(<a href=.+>\\)?\
-\\(Article\\|Noun\\|Proper Noun\\|Adjective\\|Proper Adjective\
-\\|Verb\\( form\\)?\\|Intransitive verb\\|Transitive verb\\|Adverb\
-\\|Conjunction\\|Interjection\\|Numeral\\|Prefix\\|Suffix\\|Particle\
-\\|Preposition\\|Contraction\\|Determiner\\|Demonstrative determiner\
-\\|Interrogative determiner\\|Pronoun\\|Pronominal possessive adjective\
-\\|Interrogative pronoun\\|Relative pronoun\\|Auxiliary verb\\( form\\)?\
-\\|Indefinite article\\|Abbreviation\\|Initialism\\|Acronym\\|Symbol\
-\\|Han character\\)\
-\\(</a>\\)?\
-</span>"
+			 skk-annotation-en-wiktionary-part-of-speech-regexp
 			nil t)
 		  (setq nop t)
 		  (save-match-data
@@ -1091,29 +1090,28 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 		;; ($BMQNc$J$I$r=|$/(B -- $B=|$+$J$$$[$&$,$$$$!)(B)
 		(skk-annotation-wikipedia-remove-nested "<ul>" "</ul>")
 		(skk-annotation-wikipedia-remove-nested "<dl>" "</dl>")
-		(skk-annotation-wikipedia-remove-nested "<table.*>"
+		(skk-annotation-wikipedia-remove-nested "<table[^<]*>"
 							"</table>")
+		(skk-annotation-wikipedia-remove-nested "\
+<div class=\"\\(infl-table\\|thumb.+\\)\"[^<]*>" "</div>" "<div[^<]*>")
+		(skk-annotation-wikipedia-remove-nested "\
+<span class=\"interProject\">" "</span>")
 		;; Wikipedia $B$X$N0FFb$r=|$/(B
 		(goto-char (point-min))
 		(while (re-search-forward "\
 \\(<a href=\"/wiki/Wikipedia\" title=\"Wikipedia\">\\)?\
 Wikipedia\\(</a>\\)? has an article on:$" nil t)
-		  (setq point (match-beginning 0))
+		  (save-excursion
+		    (goto-char (match-beginning 0))
+		    (beginning-of-line)
+		    (setq point (point)))
 		  (forward-line 2)
-		  (delete-region point (point)))
-		;; $BM>7W$J(B <table> $B$r=|$/(B
-		(setq point nil)
-		(goto-char (point-min))
-		(while (re-search-forward "\
-<table .*class=\"infl-table\".*>"
-					  nil t)
-		  (setq point (point))
-		  (search-forward "</table>" nil t)
+		  (end-of-line)
 		  (delete-region point (point)))
 		;;
 		(goto-char (point-min))
-		(while (re-search-forward
-			"<span.*>\\[<a.+>edit</a>\\]</span>"
+		(while (re-search-forward "\
+<span.*>\\(\\[<a.+>edit</a>\\]\\|Inflection\\)</span>"
 			nil t)
 		  (replace-match ""))))
 	     ;; ja.wikipedia
@@ -1121,7 +1119,8 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 	      (goto-char (point-min))
 	      (if (save-excursion
 		    (re-search-forward "\
-\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\\)"
+\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\
+\\|:Badtitle\\)"
 				       nil t))
 		  ;; $B9`L\$,$J$$>l9g(B
 		  (erase-buffer)
@@ -1132,15 +1131,7 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 		(search-forward "<!-- start content -->" nil t)
 		(delete-region (point-min) (point))
 		;; <div> $B$r=|5n$9$k(B
-		(setq point nil)
-		(goto-char (point-min))
-		(while (re-search-forward
-			"<div class=\"\\(magnify\\)\".*>" nil t)
-		  (setq point (match-beginning 0))
-		  (goto-char point)
-		  (search-forward "</div>" nil t)
-		  (delete-region point (point))
-		  (goto-char point))
+		(skk-annotation-wikipedia-remove-nested "<div.+>" "</div>")
 		;; <span> $B$r=|5n$9$k(B
 		(setq point nil)
 		(goto-char (point-min))
@@ -1169,8 +1160,7 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 			"<p>.+</a> &gt; \\(<a.+>\\|<b>\\).+</p>" nil t)
 		  (replace-match ""))
 		;; <table> $B$r=|5n(B
-		(skk-annotation-wikipedia-remove-nested "<table.*>"
-							"</table>")
+		(skk-annotation-wikipedia-remove-nested "<table.*>" "</table>")
 		;;
 		(goto-char (point-min))
 		(when (or (when (re-search-forward
@@ -1197,16 +1187,34 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 			    (setq nop t)))
 		  (delete-region (point-min) (point))
 		  (goto-char (point-min))
-		  (re-search-forward (if (or aimai nop)
-					 "</\\(u\\|o\\)l>"
-				       "</p>")
-				     nil t)
+		  ;;
+		  (cond
+		   ((or aimai nop)
+		    (setq pt1 (if (re-search-forward "<\\(u\\|o\\)l>" nil t)
+				  (match-end 0)
+				nil)
+			  pt2 nil)
+		    (while (and (not end)
+				(re-search-forward "</\\(u\\|o\\)l>"
+						   nil t))
+		      (setq pt2 (match-end 0))
+		      (save-excursion
+			(goto-char (or pt1 (1+ (point-min))))
+			(when (re-search-forward "<\\(u\\|o\\)l>"
+						 nil t)
+			  (setq pt1 (match-end 0))))
+		      (when (or (null pt1)
+				(> pt1 pt2))
+			(setq end t))))
+		   (t
+		    (re-search-forward "</p>" nil t)))
 		  (delete-region (point) (point-max)))))
-	     ((eq source 'en.wikipedia)
+	     ((memq source '(simple.wikipedia en.wikipedia))
 	      (goto-char (point-min))
 	      (if (save-excursion
 		    (re-search-forward "\
-\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\\)"
+\\(^HTTP/1\\.0 301 Moved Permanently\\|<div class=\"noarticletext\">\
+\\|:Badtitle\\)"
 				       nil t))
 		  ;; $B9`L\$,$J$$>l9g(B
 		  (erase-buffer)
@@ -1217,15 +1225,7 @@ Disambiguation\"" nil t)))
 		(search-forward "<!-- start content -->" nil t)
 		(delete-region (point-min) (point))
 		;; <div> $B$r=|5n$9$k(B
-		(setq point nil)
-		(goto-char (point-min))
-		(while (re-search-forward
-			"<div class=\"\\(magnify\\)\".*>" nil t)
-		  (setq point (match-beginning 0))
-		  (goto-char point)
-		  (search-forward "</div>" nil t)
-		  (delete-region point (point))
-		  (goto-char point))
+		(skk-annotation-wikipedia-remove-nested "<div.+>" "</div>")
 		;; <span> $B$r=|5n$9$k(B
 		(setq point nil)
 		(goto-char (point-min))
@@ -1282,10 +1282,27 @@ Disambiguation\"" nil t)))
 			    (setq nop t)))
 		  (delete-region (point-min) (point))
 		  (goto-char (point-min))
-		  (re-search-forward (if (or aimai nop)
-					 "</\\(u\\|o\\)l>"
-				       "</p>")
-				     nil t)
+		  ;;
+		  (cond
+		   ((or aimai nop)
+		    (setq pt1 (if (re-search-forward "<\\(u\\|o\\)l>" nil t)
+				  (match-end 0)
+				nil)
+			  pt2 nil)
+		    (while (and (not end)
+				(re-search-forward "</\\(u\\|o\\)l>"
+						   nil t))
+		      (setq pt2 (match-end 0))
+		      (save-excursion
+			(goto-char (or pt1 (1+ (point-min))))
+			(when (re-search-forward "<\\(u\\|o\\)l>"
+						 nil t)
+			  (setq pt1 (match-end 0))))
+		      (when (or (null pt1)
+				(> pt1 pt2))
+			(setq end t))))
+		   (t
+		    (re-search-forward "</p>" nil t)))
 		  (delete-region (point) (point-max))))))
 	    ;;
 	    (setq point nil)
@@ -1338,23 +1355,29 @@ Disambiguation\"" nil t)))
 	  (t
 	   nil))))
 
-(defun skk-annotation-wikipedia-remove-nested (btag etag)
+(defun skk-annotation-wikipedia-remove-nested (btag etag &optional ibtag)
   "<dl> <ul> <table> $B$J$I$NF~$l;R9=B$$r=|5n$9$k!#(B"
-  (let (point pt1 pt2)
+  (unless ibtag
+    (setq ibtag btag))
+  (let (point pt1 pt2 orig-btag)
     (setq point nil)
     (goto-char (point-min))
     (while (re-search-forward btag nil t)
       (setq point (match-beginning 0))
+      (goto-char point)
       (cond
        ((not (search-forward etag nil t))
-	(delete-region point (point-max))
+	(delete-region point (match-end 0))
 	(goto-char (point-min)))
        (t
 	(setq pt2 (match-end 0))
 	(goto-char (1+ point))
 	(cond
-	 ((not (re-search-forward btag nil t))
+	 ((not (re-search-forward ibtag nil t))
 	  (delete-region point pt2)
+	  (when orig-btag
+	    (setq btag      orig-btag
+		  orig-btag nil))
 	  (goto-char (point-min)))
 	 (t
 	  (setq pt1 (match-beginning 0))
@@ -1362,9 +1385,15 @@ Disambiguation\"" nil t)))
 	   ((< pt2 pt1)
 	    (delete-region point pt2)
 	    (setq point nil)
+	    (when orig-btag
+	      (setq btag      orig-btag
+		    orig-btag nil))
 	    (goto-char (point-min)))
 	   (t
-	    (goto-char (match-beginning 0)))))))))))
+	    (unless orig-btag
+	      (setq orig-btag btag
+		    btag      ibtag))
+	    (goto-char pt1))))))))))
 
 (defun skk-annotation-wikipedia-retrieved (&rest args)
   (cond ((or (member "deleted\n" (assq 'error (memq :error (car args))))
@@ -1510,7 +1539,7 @@ Disambiguation\"" nil t)))
 			     (url-hexify-string element)
 			   element))
 		     args))
-    (error "%s" "URL $B%Q%C%1!<%8$,MxMQ$G$-$^$;$s(B")))
+    (error "%s" "URL $B%Q%C%1!<%8$^$?$O(B Mule-UCS $B$,MxMQ$G$-$^$;$s(B")))
 
 (defun skk-annotation-wikipedia-normalize-word (word &optional source)
   ;; $B%9%Z!<%9$O(B %20 $B$G$O$J$/!"%"%s%@!<%9%3%"$KJQ49$9$k(B
@@ -1526,14 +1555,20 @@ Disambiguation\"" nil t)))
 				  ;; $BFsJ8;z$a$,(B upper case $B$J$i85$N(B case
 				  ;; $B1Q8l0J30$OL$BP1~(B
 				  word)
-			      (upcase-initials word))))
+			      ;(upcase-initials word)
+			      (concat (vector (upcase (aref word 0)))
+				      (substring word 1)))))
 
 (defun skk-annotation-url-package-available-p ()
   (when (eq skk-annotation-url-package-available-p 'untested)
     ;; Emacs 22 $B0J9_0J30$G(B URL $B%Q%C%1!<%8$r%F%9%H$9$k(B
     (cond
-     ((and (eq skk-emacs-type 'mule4)
-	   (string-lessp mule-version "4.1"))
+     ((or (and (eq skk-emacs-type 'mule4)
+	       (string-lessp mule-version "4.1"))
+	  (and (not (and (featurep 'xemacs)
+			 (string< "21.5" emacs-version)))
+	       (not (ignore-errors
+		      (require 'un-define)))))
       ;; Emacs 20.7 (MULE 4.0) $B$G$O%5%]!<%H$7$J$$(B
       (setq skk-annotation-url-package-available-p nil))
      (t
