@@ -224,11 +224,23 @@
 ;;;###autoload
 (defun skk-e21-prepare-modeline-properties ()
   (setq skk-icon
-	(let* ((dir (file-name-directory skk-tut-file))
-	       (image (find-image
-		       `((:type xpm
-				:file ,(expand-file-name "skk.xpm" dir)
-				:ascent center))))
+	(let* ((dir (ignore-errors
+		      (file-name-directory
+		       (static-if (fboundp 'locate-file)
+			   ;; Emacs 22.1 or later
+			   (or (locate-file "skk/skk.xpm"
+					    (list (expand-file-name
+						   "../../.."
+						   data-directory)))
+			       (locate-file "skk/skk.xpm"
+					    (list data-directory)))
+			 ;; Emacs 21
+			 skk-tut-file))))
+	       (image (when dir
+			(find-image
+			 `((:type xpm
+				  :file ,(expand-file-name "skk.xpm" dir)
+				  :ascent center)))))
 	       (string "dummy"))
 	  (if (and skk-show-icon window-system image)
 	      (apply 'propertize string
@@ -318,6 +330,10 @@
 
 (defun skk-tooltip-resize-text (text)
   (let ((lines 0)
+	(max-lines
+	 ;; $B2hLL$NH>J,$N9b$5$r4p=`$K:GBg9b$r7h$a$k(B
+	 (- (/ (/ (display-pixel-height) 2) (frame-char-height))
+	    2))
 	(columns 0)
 	(current-column nil))
     (with-temp-buffer
@@ -326,7 +342,7 @@
       (goto-char (point-min))
       (while (not (eobp))
 	(setq lines (1+ lines))
-	(cond ((= lines 35)
+	(cond ((= lines max-lines)
 	       ;; $BD9$9$.$k(B
 	       (beginning-of-line)
 	       (insert "($BD9$9$.$k$N$G>JN,$5$l$^$7$?(B)")
@@ -490,7 +506,7 @@
     (skk-tooltip-show-1 text parameters)
     ;;
     (when (eq situation 'annotation)
-      (skk-annotation-wikipedia-message))
+      (skk-annotation-message situation))
     ;;
     (setq event (next-command-event))
     (cond
