@@ -5,9 +5,9 @@
 
 ;; Author: Enami Tsugutomo <enami@ba2.so-net.or.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-isearch.el,v 1.51 2007/04/24 23:13:37 skk-cvs Exp $
+;; Version: $Id: skk-isearch.el,v 1.56 2007/08/02 08:22:35 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/04/24 23:13:37 $
+;; Last Modified: $Date: 2007/08/02 08:22:35 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -67,11 +67,13 @@
 ;;
 (defsubst skk-isearch-turn-off-skk-mode ()
   "Turn off skk mode."
-  (skk-mode 0))
+  (let ((skk-use-color-cursor nil))
+    (skk-mode 0)))
 
 (defsubst skk-isearch-turn-on-skk-mode ()
   "Turn on skk mode."
-  (skk-mode 1))
+  (let ((skk-use-color-cursor nil))
+    (skk-mode 1)))
 
 (defsubst skk-isearch-conversion-active-p ()
   "Non-nil if skk conversion is active."
@@ -83,7 +85,8 @@
 
 (defsubst skk-isearch-skk-kakutei ()
   "Perform kakutei."
-  (skk-kakutei))
+  (let ((skk-use-color-cursor nil))
+    (skk-kakutei)))
 
 (defsubst skk-isearch-skk-hiragana-mode-p ()
   "Non-nil if skk is hiragana input mode."
@@ -91,7 +94,8 @@
 
 (defsubst skk-isearch-skk-turn-on-hiragana-mode ()
   "Set current skk mode to hiragana input mode."
-  (skk-j-mode-on))
+  (let ((skk-use-color-cursor nil))
+    (skk-j-mode-on)))
 
 (defsubst skk-isearch-skk-katakana-mode-p ()
   "Non-nil if skk is katakana input mode."
@@ -99,7 +103,8 @@
 
 (defsubst skk-isearch-skk-turn-on-katakana-mode ()
   "Set current skk mode to katakana input mode."
-  (skk-j-mode-on 'katakana))
+  (let ((skk-use-color-cursor nil))
+    (skk-j-mode-on 'katakana)))
 
 (defsubst skk-isearch-skk-jisx0208-latin-mode-p ()
   "Non-nil if skk is jisx0208 latin (zenkaku) input mode."
@@ -111,11 +116,19 @@
 
 (defsubst skk-isearch-skk-turn-on-jix0208-latin-mode ()
   "Set current skk mode to jisx0208 latin (zenkaku) input mode."
-  (skk-jisx0208-latin-mode-on))
+  (let ((skk-use-color-cursor nil))
+    (skk-jisx0208-latin-mode-on)))
 
 (defsubst skk-isearch-skk-turn-on-latin-mode ()
   "Set current skk mode to normal latin input mode."
-  (skk-latin-mode-on))
+  (let ((skk-use-color-cursor nil))
+    (skk-latin-mode-on)))
+
+(defun skk-isearch-buffer-string ()
+  (if (and skk-echo
+	   skk-prefix)
+      (concat (buffer-string) skk-prefix)
+    (buffer-string)))
 
 ;;;###autoload
 (defun skk-isearch-message ()
@@ -299,12 +312,9 @@ kakutei'ed and erase the buffer contents."
     (setq skk-isearch-state nil))
   (setq skk-isearch-current-buffer nil)
   ;;
-  (remove-hook 'pre-command-hook 'skk-pre-command 'local)
-  (skk-remove-minibuffer-setup-hook
-   'skk-j-mode-on 'skk-setup-minibuffer
-   (function
-    (lambda ()
-      (add-hook 'pre-command-hook 'skk-pre-command nil 'local)))))
+  (skk-remove-minibuffer-setup-hook 'skk-j-mode-on
+				    'skk-setup-minibuffer
+				    'skk-add-skk-pre-command))
 
 (defun skk-isearch-incomplete-message (&optional prefix)
   "Show message when kana kanji conversion is in progress.
@@ -448,10 +458,10 @@ If the conversion is in progress and no string is fixed, just return nil."
 		;; whole string in the buffer is fixed.
 		((not (zerop (buffer-size)))
 		 (prog1
-		     (buffer-string)
+		     (skk-isearch-buffer-string)
 		   (erase-buffer))))
 	;; update incomplete-message with contents of working buffer.
-	(setq skk-isearch-incomplete-message (buffer-string))
+	(setq skk-isearch-incomplete-message (skk-isearch-buffer-string))
 	;; update echo area.
 	(skk-isearch-incomplete-message))))
 
@@ -524,7 +534,7 @@ If the current mode is different from previous, remove it first."
 		    (skk-kakutei))
 		  (delete-backward-char 1)
 		  (setq isearch-string (concat isearch-string
-					       (buffer-string))
+					       (skk-isearch-buffer-string))
 			isearch-message (concat
 					 (skk-isearch-mode-string)
 					 (mapconcat
@@ -544,7 +554,8 @@ If the current mode is different from previous, remove it first."
 		    (delete-backward-char 1))
 		   (t
 		    (skk-erase-prefix 'clean)))
-		  (setq skk-isearch-incomplete-message (buffer-string))
+		  (setq skk-isearch-incomplete-message
+			(skk-isearch-buffer-string))
 		  (skk-isearch-incomplete-message))))))
     ;;
     (let* ((cmd (nth 1 isearch-cmds))
