@@ -1,4 +1,4 @@
-;;; skk-kcode.el --- $B4A;z%3!<%I$r;H$C$?JQ49$N$?$a$N%W%m%0%i%`(B
+;;; skk-kcode.el --- $B4A;z%3!<%I$r;H$C$?JQ49$N$?$a$N%W%m%0%i%`(B -*- coding: iso-2022-jp -*-
 
 ;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997,
 ;;               1998, 1999, 2000
@@ -6,9 +6,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kcode.el,v 1.29 2002/10/26 09:37:27 minakaji Exp $
+;; Version: $Id: skk-kcode.el,v 1.34 2007/04/22 02:38:26 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2002/10/26 09:37:27 $
+;; Last Modified: $Date: 2007/04/22 02:38:26 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -24,8 +24,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with Daredevil SKK, see the file COPYING.  If not, write to
-;; the Free Software Foundation Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; the Free Software Foundation Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -213,11 +213,11 @@
 		   (cond
 		    (ch
 		     ch)
-		    ((eq char ?x)
+		    ((eq char skk-previous-candidate-char)
 		     (when (< (setq n (- n-org 2)) skk-code-n1-min)
 		       (setq n skk-code-n1-max))
 		     nil)
-		    ((eq char ?\040)
+		    ((eq char skk-start-henkan-char) ; space
 		     (setq n (skk-next-n1-code n))
 		     nil)
 		    ((eq char ?\?)
@@ -258,7 +258,7 @@
       (let ((n1-org n1) (n2-org n2) (i 0)
 	    (chars (list (skk-make-string n1 n2))))
 	;; 16 == (length skk-input-by-code-menu-keys2)
-	(while (< i 16)
+	(while (< i (1- 16))
 	  (nconc chars (list
 			(progn
 			  (setq n2 (skk-next-n2-code n2))
@@ -300,12 +300,12 @@
 		   (cond
 		    (ch
 		     ch)
-		    ((eq char ?x)
+		    ((eq char skk-previous-candidate-char)
 		     (when (< (setq n2 (- n2 31)) skk-code-n2-min)
 		       (setq n2 (+ n2 94)
 			     n1 (skk-previous-n1-code n1)))
 		     nil)
-		    ((eq char ?\040) ; space
+		    ((eq char skk-start-henkan-char) ; space
 		     (if (= (setq n2 (skk-next-n2-code n2))
 			    skk-code-n2-min)
 			 (setq n1 (skk-next-n1-code n1)))
