@@ -4,9 +4,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@namazu.org>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-look.el,v 1.40 2007/04/22 02:38:26 skk-cvs Exp $
+;; Version: $Id: skk-look.el,v 1.41 2007/07/27 13:33:11 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/04/22 02:38:26 $
+;; Last Modified: $Date: 2007/07/27 13:33:11 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -225,8 +225,6 @@ words $B%U%!%$%k$K$"$kA4$F$N8+=P$7$,BP>]$H$J$k!#(B
 
 ;;;###autoload
 (defun skk-look-completion (&optional completion-arguments not-abbrev-only expand-null)
-  ;; skk-comp-prefix $B$O;H$o$J$$$N$G!"(B
-  ;; $BI,MW$J$i(B skk-comp-restrict-by-prefix() $B$rJ;MQ$9$k!#(B
   "look $B%3%^%s%I$rMxMQ$7$FJd408uJd$rF@$k!#(B
 COMPLETION-ARGUMENTS $B$O(B `skk-look-completion-arguments' $B$r(B
 $B0l;~E*$KCV$-49$($?$$;~$K;XDj$9$k!#(B
@@ -259,6 +257,15 @@ words $B%U%!%$%k$K$"$kA4$F$N8+=P$7$rJV$9!#(B
 		    (skk-look-ispell comp-key 'completion)
 		  (skk-look-1 comp-key 'completion))))
 	(setq word (pop skk-look-completion-words))
+	(when (and skk-comp-use-prefix
+		   (not (string= skk-comp-prefix "")))
+	  (save-match-data
+	    (let ((regexp-key (concat "^"
+				      (regexp-quote comp-key)
+				      (skk-comp-get-regexp skk-comp-prefix))))
+	      (while (and word
+			  (not (string-match regexp-key word)))
+		(setq word (pop skk-look-completion-words))))))
 	(when word
 	  (if numericp
 	      (concat skk-comp-key
