@@ -4,9 +4,9 @@
 
 ;; Author: SKK Development Team <skk@ring.gr.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.114 2007/04/27 07:07:25 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.120 2007/08/13 23:37:24 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/04/27 07:07:25 $
+;; Last Modified: $Date: 2007/08/13 23:37:24 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -561,29 +561,24 @@ BUFFER defaults to the current buffer."
   (assq char (skk-get-branch-list tree)))
 
 (defun skk-erase-prefix (&optional clean)
-  "`skk-echo' $B$,Hs(B nil $B$G$"$l$P8=:_$N%P%C%U%!$KA^F~$5$l$?(B `skk-prefix' $B$r>C$9!#(B
+  "`skk-echo' $B$,Hs(B nil $B$G$"$l$P8=:_I=<($5$l$F$$$k(B `skk-prefix' $B$r>C$9!#(B
 $B%*%W%7%g%s0z?t$N(B CLEAN $B$,;XDj$5$l$k$H!"JQ?t$H$7$F$N(B `skk-prefix' $B$r6uJ8;z$K!"(B
 `skk-current-rule-tree' $B$r(B nil $B$K=i4|2=$9$k!#(B"
-
-  ;; $B$+$JJ8;z$NF~NO$,$^$@40@.$7$F$$$J$$>l9g$K$3$N4X?t$,8F$P$l$?$H$-$J$I$O!"%P%C(B
-  ;; $B%U%!$KA^F~$5$l$F$$$k(B skk-prefix $B$O:o=|$7$?$$$,!"JQ?t$H$7$F$N(B skk-prefix $B$O(B
+  ;; $B$+$JJ8;z$NF~NO$,$^$@40@.$7$F$$$J$$>l9g$K$3$N4X?t$,8F$P$l$?$H$-$J$I$O(B
+  ;; $BI=<($5$l$F$$$k(B skk-prefix $B$O:o=|$7$?$$$,!"JQ?t$H$7$F$N(B skk-prefix $B$O(B
   ;; null $BJ8;z$K$7$?$/$J$$!#(B
-  (when (and skk-echo
-	     skk-kana-start-point
-	     (not (string= skk-prefix ""))) ; fail safe.
-    (let ((start (marker-position skk-kana-start-point)))
-      (when start
+  (when (overlayp skk-prefix-overlay)
 	(condition-case nil
-	    ;; skk-prefix $B$N>C5n$r%"%s%I%%$NBP>]$H$7$J$$!#(B
-	    (skk-cannot-be-undone
-	     (delete-region start (+ start (length skk-prefix))))
+	    (delete-overlay skk-prefix-overlay)
 	  (error
 	   (skk-set-marker skk-kana-start-point nil)
 	   (setq skk-prefix ""
-		 skk-current-rule-tree nil))))))
+		 skk-current-rule-tree nil))))
   (when clean
     (setq skk-prefix ""
-	  skk-current-rule-tree nil))) ; fail safe
+	  skk-current-rule-tree nil)) ; fail safe
+  (static-when (eq skk-emacs-type 'mule4)
+    (redraw-frame (selected-frame))))
 
 (defun skk-kana-cleanup (&optional force)
   (let ((data (cond
@@ -641,7 +636,7 @@ BUFFER defaults to the current buffer."
   ;; initialize
   (skk-update-modeline)
   (skk-cursor-off)
-  (remove-hook 'pre-command-hook 'skk-pre-command 'local))
+  (skk-remove-skk-pre-command))
 
 (defun skk-j-mode-on (&optional katakana)
   (setq skk-mode t
@@ -708,14 +703,15 @@ BUFFER defaults to the current buffer."
   "$B%+%l%s%H%P%C%U%!$,%_%K%P%C%U%!$+$I$&$+$r%A%'%C%/$9$k!#(B"
   (eq (current-buffer) (window-buffer (minibuffer-window))))
 
-(defsubst skk-insert-prefix (&optional char)
+(defun skk-insert-prefix (&optional char)
   "`skk-echo' $B$,(B non-nil $B$G$"$l$P%+%l%s%H%P%C%U%!$K(B `skk-prefix' $B$rA^F~$9$k!#(B"
   (when skk-echo
-    ;; skk-prefix $B$NA^F~$r%"%s%I%%$NBP>]$H$7$J$$!#A^F~$7$?%W%l%U%#%C%/%9$O!"(B
-    ;; $B$+$JJ8;z$rA^F~$9$kA0$KA4$F>C5n$9$k$N$G!"$=$N4V!"(Bbuffer-undo-list $B$r(B
-    ;; t $B$K$7$F%"%s%I%%>pJs$rC_$($J$/$H$bLdBj$,$J$$!#(B
-    (skk-cannot-be-undone
-     (insert-and-inherit (or char skk-prefix)))))
+    ;; skk-prefix $B$O%"%s%I%%$NBP>]$H$J$i$J$$$N$G(B
+    ;; $B%P%C%U%!$KA^F~$5$l$kI,MW$,$J$$!#(B
+    (setq skk-prefix-overlay (make-overlay (point) (point)))
+    (overlay-put skk-prefix-overlay 'after-string (or char skk-prefix))
+    (static-when (eq skk-emacs-type 'mule4)
+      (redraw-frame (selected-frame)))))
 
 (defsubst skk-string-lessp-in-coding-system (str1 str2 coding-system)
   (string< (encode-coding-string str1 coding-system)
