@@ -7,9 +7,9 @@
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>,
 ;;         Murata Shuuichirou <mrt@notwork.org>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-viper.el,v 1.34 2007/04/22 02:38:27 skk-cvs Exp $
+;; Version: $Id: skk-viper.el,v 1.36 2007/06/28 13:10:59 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/04/22 02:38:27 $
+;; Last Modified: $Date: 2007/06/28 13:10:59 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -157,12 +157,10 @@ viper-read-string-with-history $B$O(B minibuffer-setup-hook $B$r4X?t%m!<%+%k
 ;; vip-4 $B$NF1<o$N4X?tL>$O(B vip-read-string-with-history$B!)(B
 (defadvice viper-read-string-with-history (after skk-viper-ad activate)
   "$B<!2s%_%K%P%C%U%!$KF~$C$?$H$-$K(B SKK $B%b!<%I$K$J$i$J$$$h$&$K$9$k!#(B"
-  (remove-hook 'pre-command-hook 'skk-pre-command 'local)
-  (skk-remove-minibuffer-setup-hook
-   'skk-j-mode-on 'skk-setup-minibuffer
-   (function
-    (lambda ()
-      (add-hook 'pre-command-hook 'skk-pre-command nil 'local)))))
+  (skk-remove-skk-pre-command)
+  (skk-remove-minibuffer-setup-hook 'skk-j-mode-on
+				    'skk-setup-minibuffer
+				    'skk-add-skk-pre-command))
 
 (skk-viper-advice-select
  viper-forward-word-kernel vip-forward-word-kernel
@@ -198,7 +196,8 @@ viper-read-string-with-history $B$O(B minibuffer-setup-hook $B$r4X?t%m!<%+%k
     (cond
      ((eq skk-henkan-mode 'active)
       (if (and (not skk-delete-implies-kakutei)
-	       (= skk-henkan-end-point (point)))
+	       (= (+ skk-henkan-end-point (length skk-henkan-okurigana))
+		  (point)))
 	  (skk-previous-candidate)
 	;;(if skk-use-face (skk-henkan-face-off))
 	;; overwrite-mode $B$G!"%]%$%s%H$,A43QJ8;z$K0O$^$l$F$$$k$H(B
