@@ -240,6 +240,11 @@
 
 (defun skk-tooltip-resize-text (text)
   (let ((lines 0)
+	(max-lines
+	 ;; $B2hLL$NH>J,$N9b$5$r4p=`$K:GBg9b$r7h$a$k(B
+	 (- (/ (/ (display-pixel-height) 2)
+	       (cdr (assq 'PIXEL_SIZE (font-properties (face-font 'default)))))
+	    2))
 	(columns 0)
 	(current-column nil))
     (with-temp-buffer
@@ -248,7 +253,7 @@
       (goto-char (point-min))
       (while (not (eobp))
 	(setq lines (1+ lines))
-	(cond ((= lines 35)
+	(cond ((= lines max-lines)
 	       ;; $BD9$9$.$k(B
 	       (beginning-of-line)
 	       (insert "($BD9$9$.$k$N$G>JN,$5$l$^$7$?(B)")
@@ -357,7 +362,7 @@
     (skk-tooltip-show-1 text (eq situation 'listing))
     ;;
     (when (eq situation 'annotation)
-      (skk-annotation-wikipedia-message))
+      (skk-annotation-message situation))
     ;;
     (setq event (next-command-event))
     (cond
