@@ -1,33 +1,37 @@
-;;; skk-tutcdef.el --- SKK TUT-code default definition.
+;;; skk-tutcdef.el --- SKK TUT-code default definition -*- coding: iso-2022-jp -*-
+
 ;; Copyright (C) 1999, 2000 GUNJI Takao <gunji@sils.shoin.ac.jp>
 
 ;; Author: GUNJI Takao <gunji@sils.shoin.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tutcdef.el,v 1.1 2000/12/12 08:59:42 minakaji Exp $
-;; Keywords: japanese
-;; Last Modified: $Date: 2000/12/12 08:59:42 $
+;; Version: $Id: skk-tutcdef.el,v 1.11 2007/04/22 02:38:28 skk-cvs Exp $
+;; Keywords: japanese, mule, input method
+;; Last Modified: $Date: 2007/04/22 02:38:28 $
 
 ;; This file is part of Daredevil SKK.
 
-;; Daredevil SKK is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either versions 2, or (at your option)
-;; any later version.
+;; Daredevil SKK is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation; either version 2, or
+;; (at your option) any later version.
 
-;; Daredevil SKK is distributed in the hope that it will be useful
+;; Daredevil SKK is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with Daredevil SKK, see the file COPYING.  If not, write to the Free
-;; Software Foundation Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; along with Daredevil SKK, see the file COPYING.  If not, write to
+;; the Free Software Foundation Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
 ;;; Code:
-(eval-when-compile (require 'skk) (require 'skk-tutcode))
+
+(eval-when-compile
+  (require 'skk)
+  (require 'skk-tutcode))
 
 (define-key skk-j-mode-map "\C-l" 'skk-latin-mode)
 (setq skk-try-completion-char ?\016)	; \C-n
@@ -47,13 +51,14 @@
    ("X" nil skk-purge-from-jisyo)
    ("\\" nil skk-tutcode-mode-off)
    ("\t" nil skk-toggle-kana)
-   ("^" nil skk-input-by-code-or-menu) ))
+   ("^" nil skk-input-by-code-or-menu)
+   ("\C-@" nil skk-start-henkan)))
 
-(if (and (eq skk-emacs-type 'xemacs) (= emacs-major-version 20))
-    (progn
-      (setq skk-rom-kana-base-rule-list
-	    (delete '("\t" nil skk-toggle-kana) skk-rom-kana-base-rule-list) )
-      (define-key skk-j-mode-map "\t" 'skk-toggle-kana) ))
+;; (if (and (eq skk-emacs-type 'xemacs) (= emacs-major-version 20))
+;;     (progn
+;;       (setq skk-rom-kana-base-rule-list
+;;	    (delete '("\t" nil skk-toggle-kana) skk-rom-kana-base-rule-list))
+;;       (define-key skk-j-mode-map "\t" 'skk-toggle-kana)))
 
 ;; The first few entries are necessary to disable special treatments of
 (setq skk-rom-kana-rule-list
@@ -947,9 +952,12 @@
     (setq skk-rom-kana-rule-list
 	  (nconc '(("tld" nil "$B$Q(B") ("tle" nil "$B$T(B") ("tlr" nil "$B$W(B")
 		   ("tlg" nil "$B$Z(B") ("tlf" nil "$B$](B") ("dlr" nil "$B$E(B")
-		   ("alu" nil "$B%t(B") ("eld" nil "$B%u(B") ("elg" nil "$B%v(B") )
-		 skk-rom-kana-rule-list )))
+		   ("alu" nil "$B%t(B") ("eld" nil "$B%u(B") ("elg" nil "$B%v(B"))
+		 skk-rom-kana-rule-list)))
 
 (require 'product)
-(product-provide (provide 'skk-tutcdef) (require 'skk-version))
+(product-provide
+    (provide 'skk-tutcdef)
+  (require 'skk-version))
+
 ;;; skk-tutcdef.el ends here
